@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: binary-tagged
 version: 0.1.3.1
-id: binary-tagged-0.1.3.1-101f042861e5610dd2e62eedde2de570
-key: binar_59BLVaKqSRFJDVS80kW31l
+id: binary-tagged-0.1.3.1-8f48aa428192447e485cc7cb7feaa64a
+key: binar_IUMzZtW6iIE2UoGnbdsK6w
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/binary-tagged#readme
@@ -19,22 +19,22 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.3.1
-hs-libraries: HSbinary-tagged-0.1.3.1-59BLVaKqSRFJDVS80kW31l
+hs-libraries: HSbinary-tagged-0.1.3.1-IUMzZtW6iIE2UoGnbdsK6w
 depends:
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
+    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     generics-sop-0.2.1.0-7239eda8d6e847745310ee1c6aedf3ba
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
 haddock-html: /usr/share/doc/haskell-binary-tagged/html
